@@ -8,7 +8,6 @@ if six.PY3 and not sys.version_info.minor == 5:  # All python 3 expect for 3.5
 else:
     SpeedtestdotnetMeasurementResult = collections.namedtuple(
         "SpeedtestdotnetMeasurementResult",
-        "id errors host minimum_latency average_latency maximum_latency median_deviation "
-        "packets_transmitted packets_received packets_lost packets_lost_unit time time_unit",
+        "id errors download_rate download_rate_unit upload_rate upload_rate_unit"
+        "latency server_name server_id server_sponsor server_host",
     )
-
